@@ -2,7 +2,7 @@ import inspect
 import os
 import sys
 import traceback
-from collections.abc import Iterable, Iterator
+from collections.abc import Coroutine, Iterable, Iterator
 from contextlib import suppress
 from copy import copy
 from enum import Enum
@@ -251,6 +251,7 @@ class App:
             "rich",
         ]
     ] = field(default=None, kw_only=True)
+    help_on_error: Optional[bool] = field(default=None, kw_only=True)
 
     version_format: Optional[
         Literal[
@@ -306,6 +307,8 @@ class App:
         kw_only=True,
     )
 
+    end_of_options_delimiter: Optional[str] = field(default=None, kw_only=True)
+
     ######################
     # Private Attributes #
     ######################
@@ -423,10 +426,7 @@ class App:
 
     @property
     def config(self) -> tuple[str, ...]:
-        if self._config is None and self._meta_parent is not None:
-            return self._meta_parent.config
-        else:
-            return self._config or ()  # pyright: ignore[reportReturnType]
+        return self._resolve(None, None, "_config")  # pyright: ignore[reportReturnType]
 
     @config.setter
     def config(self, value):
@@ -862,6 +862,7 @@ class App:
         tokens: Union[None, str, Iterable[str]] = None,
         *,
         console: Optional["Console"] = None,
+        end_of_options_delimiter: Optional[str] = None,
     ) -> tuple[Callable, inspect.BoundArguments, list[str], dict[str, Any]]:
         """Interpret arguments into a registered function, :class:`~inspect.BoundArguments`, and any remaining unknown tokens.
 
@@ -873,6 +874,11 @@ class App:
         console: rich.console.Console
             Console to print help and runtime Cyclopts errors.
             If not provided, follows the resolution order defined in :attr:`App.console`.
+        end_of_options_delimiter: Optional[str]
+            All tokens after this delimiter will be force-interpreted as positional arguments.
+            If :obj:`None`, fallback to :class:`App.end_of_options_delimiter`.
+            If that is not set, it will default to POSIX-standard ``"--"``.
+            Set to an empty string to disable.
 
         Returns
         -------
@@ -891,14 +897,17 @@ class App:
             :obj:`~typing.Annotated` will be resolved.
             Intended to simplify :ref:`meta apps <Meta App>`.
         """
-        command, bound, unused_tokens, ignored, argument_collection = self._parse_known_args(tokens, console=console)
+        command, bound, unused_tokens, ignored, argument_collection = self._parse_known_args(
+            tokens, console=console, end_of_options_delimiter=end_of_options_delimiter
+        )
         return command, bound, unused_tokens, ignored
 
     def _parse_known_args(
         self,
         tokens: Union[None, str, Iterable[str]] = None,
         *,
-        console: Optional["Console"] = None,
+        console: Optional["Console"],
+        end_of_options_delimiter: Optional[str],
     ) -> tuple[Callable, inspect.BoundArguments, list[str], dict[str, Any], ArgumentCollection]:
         if tokens is None:
             _log_framework_warning(_detect_test_framework())
@@ -923,12 +932,11 @@ class App:
         except IndexError:
             parent_app = None
 
-        config: tuple[Callable, ...] = ()
-        for app in reversed(apps):
-            if app.config:
-                config = app.config  # pyright: ignore[reportAssignmentType]
-                break
+        config: tuple[Callable, ...] = self._resolve(apps, None, "_config") or ()
         config = tuple(partial(x, apps, command_chain) for x in config)
+        end_of_options_delimiter = self._resolve(apps, end_of_options_delimiter, "end_of_options_delimiter")
+        if end_of_options_delimiter is None:
+            end_of_options_delimiter = "--"
 
         # Special flags (help/version) get intercepted by the root app.
         # Special flags are allows to be **anywhere** in the token stream.
@@ -978,6 +986,7 @@ class App:
                         argument_collection,
                         unused_tokens,
                         config,
+                        end_of_options_delimiter=end_of_options_delimiter,
                     )
                     try:
                         for validator in command_app.validator:
@@ -1023,7 +1032,9 @@ class App:
         console: Optional["Console"] = None,
         print_error: bool = True,
         exit_on_error: bool = True,
+        help_on_error: Optional[bool] = None,
         verbose: bool = False,
+        end_of_options_delimiter: Optional[str] = None,
     ) -> tuple[Callable, inspect.BoundArguments, dict[str, Any]]:
         """Interpret arguments into a function and :class:`~inspect.BoundArguments`.
 
@@ -1042,14 +1053,22 @@ class App:
             If not provided, follows the resolution order defined in :attr:`App.console`.
         print_error: bool
             Print a rich-formatted error on error.
-            Defaults to ``True``.
+            Defaults to :obj:`True`.
         exit_on_error: bool
             If there is an error parsing the CLI tokens invoke ``sys.exit(1)``.
             Otherwise, continue to raise the exception.
-            Defaults to ``True``.
+            Defaults to :obj:`True`.
+        help_on_error: bool
+            Prints the help-page before printing an error, overriding :attr:`App.help_on_error`.
+            Defaults to :obj:`None` (interpret from :class:`.App`, eventually defaulting to :obj:`False`).
         verbose: bool
             Populate exception strings with more information intended for developers.
-            Defaults to ``False``.
+            Defaults to :obj:`False`.
+        end_of_options_delimiter: Optional[str]
+            All tokens after this delimiter will be force-interpreted as positional arguments.
+            If :obj:`None`, fallback to :class:`App.end_of_options_delimiter`.
+            If that is not set, it will default to POSIX-standard ``"--"``.
+            Set to an empty string to disable.
 
         Returns
         -------
@@ -1068,11 +1087,12 @@ class App:
             _log_framework_warning(_detect_test_framework())
 
         tokens = normalize_tokens(tokens)
+        help_on_error = self._resolve(tokens, help_on_error, "help_on_error") or False
 
         # Normal parsing
         try:
             command, bound, unused_tokens, ignored, argument_collection = self._parse_known_args(
-                tokens, console=console
+                tokens, console=console, end_of_options_delimiter=end_of_options_delimiter
             )
             if unused_tokens:
                 for token in unused_tokens:
@@ -1091,6 +1111,9 @@ class App:
 
             if e.console is None:
                 e.console = self._resolve_console(tokens, console)
+            if help_on_error:
+                assert e.console
+                self.help_print(tokens, console=e.console)
             if print_error:
                 assert e.console
                 e.console.print(format_cyclopts_error(e))
@@ -1107,7 +1130,9 @@ class App:
         console: Optional["Console"] = None,
         print_error: bool = True,
         exit_on_error: bool = True,
+        help_on_error: Optional[bool] = None,
         verbose: bool = False,
+        end_of_options_delimiter: Optional[str] = None,
     ):
         """Interprets and executes a command.
 
@@ -1121,14 +1146,21 @@ class App:
             If not provided, follows the resolution order defined in :attr:`App.console`.
         print_error: bool
             Print a rich-formatted error on error.
-            Defaults to ``True``.
+            Defaults to :obj:`True`.
         exit_on_error: bool
             If there is an error parsing the CLI tokens invoke ``sys.exit(1)``.
             Otherwise, continue to raise the exception.
             Defaults to ``True``.
+        help_on_error: bool
+            Prints the help-page before printing an error, overriding :attr:`App.help_on_error`.
+            Defaults to :obj:`None` (interpret from :class:`.App`, eventually defaulting to :obj:`False`).
         verbose: bool
             Populate exception strings with more information intended for developers.
-            Defaults to ``False``.
+            Defaults to :obj:`False`.
+        end_of_options_delimiter: Optional[str]
+            All tokens after this delimiter will be force-interpreted as positional arguments.
+            If :obj:`None`, fallback to :class:`App.end_of_options_delimiter`.
+            If that is not set, it will default to POSIX-standard ``"--"``.
 
         Returns
         -------
@@ -1144,7 +1176,9 @@ class App:
             console=console,
             print_error=print_error,
             exit_on_error=exit_on_error,
+            help_on_error=help_on_error,
             verbose=verbose,
+            end_of_options_delimiter=end_of_options_delimiter,
         )
         try:
             if inspect.iscoroutinefunction(command):
@@ -1168,15 +1202,35 @@ class App:
                     sys.exit(1)
             raise
 
-    def _resolve_console(
-        self, tokens: Union[None, str, Iterable[str]], console: Optional["Console"] = None
-    ) -> "Console":
-        if console is not None:
-            return console
-        _, apps, _ = self.parse_commands(tokens)
+    def _resolve(self, tokens_or_apps: Optional[Sequence], override: Optional[V], attribute: str) -> Optional[V]:
+        if override is not None:
+            return override
+
+        if not tokens_or_apps:
+            apps = (self,)
+        elif isinstance(tokens_or_apps[0], App):
+            apps = tokens_or_apps
+        else:
+            _, apps, _ = self.parse_commands(tokens_or_apps)
+
         for app in reversed(apps):
-            if app.console:
-                return app.console
+            result = getattr(app, attribute)
+            if result is not None:
+                return result
+
+            # Check parenting meta app(s)
+            meta_app = app
+            while (meta_app := meta_app._meta_parent) is not None:
+                result = getattr(meta_app, attribute)
+                if result is not None:
+                    return result
+
+        return None
+
+    def _resolve_console(self, tokens_or_apps: Optional[Sequence], override: Optional["Console"] = None) -> "Console":
+        result = self._resolve(tokens_or_apps, override, "console")
+        if result is not None:
+            return result
         from rich.console import Console
 
         return Console()
@@ -1480,7 +1534,15 @@ def _log_framework_warning(framework: TestFramework) -> None:
         break
 
 
-def run(callable: Callable[..., V], /) -> V:
+@overload
+def run(callable: Callable[..., Coroutine[None, None, V]], /) -> V: ...
+
+
+@overload
+def run(callable: Callable[..., V], /) -> V: ...
+
+
+def run(callable, /):
     """Run the given callable as a CLI command and return its result.
 
     The callable may also be a coroutine function.
