@@ -1,13 +1,13 @@
 import sys
 from enum import Enum
 from textwrap import dedent
-from typing import Annotated, List, Literal, Optional, Set, Tuple, Union
+from typing import Annotated, List, Literal, Optional, Sequence, Set, Tuple, Union
 
 import pytest
 
 from cyclopts import App, Group, Parameter
 from cyclopts.argument import ArgumentCollection
-from cyclopts.exceptions import MissingArgumentError
+from cyclopts.exceptions import CoercionError, MissingArgumentError
 from cyclopts.help import (
     HelpPanel,
     create_parameter_help_panel,
@@ -649,6 +649,52 @@ def test_help_format_group_parameters_choices_enum_list_typing(capture_format_gr
     assert actual == expected
 
 
+def test_help_format_group_parameters_choices_enum_sequence(capture_format_group_parameters):
+    class CompSciProblem(Enum):
+        fizz = "bleep bloop blop"
+        buzz = "blop bleep bloop"
+
+    def cmd(
+        foo: Annotated[
+            Optional[Sequence[CompSciProblem]],  # pyright: ignore
+            Parameter(help="Docstring for foo.", negative_iterable=(), show_default=False, show_choices=True),
+        ] = None,
+    ):
+        pass
+
+    actual = capture_format_group_parameters(cmd)
+    expected = dedent(
+        """\
+        ╭─ Parameters ───────────────────────────────────────────────────────╮
+        │ FOO --foo  Docstring for foo. [choices: fizz, buzz]                │
+        ╰────────────────────────────────────────────────────────────────────╯
+        """
+    )
+    assert actual == expected
+
+
+def test_help_format_group_parameters_choices_literal_sequence(capture_format_group_parameters):
+    def cmd(
+        steps_to_skip: Annotated[
+            Optional[Sequence[Literal["build", "deploy"]]],  # pyright: ignore
+            Parameter(help="Docstring for steps_to_skip.", negative_iterable=(), show_default=False, show_choices=True),
+        ] = None,
+    ):
+        pass
+
+    actual = capture_format_group_parameters(cmd)
+    expected = dedent(
+        """\
+        ╭─ Parameters ───────────────────────────────────────────────────────╮
+        │ STEPS-TO-SKIP      Docstring for steps_to_skip. [choices: build,   │
+        │   --steps-to-skip  deploy]                                         │
+        ╰────────────────────────────────────────────────────────────────────╯
+        """
+    )
+    print(expected)
+    assert actual == expected
+
+
 def test_help_format_group_parameters_choices_literal_set(capture_format_group_parameters):
     def cmd(
         steps_to_skip: Annotated[
@@ -1726,3 +1772,33 @@ def test_help_consistent_formatting(app, console):
     actual_cmd_help = actual_cmd_help.strip()
 
     assert actual_help == actual_cmd_help
+
+
+def test_help_help_on_error(app, console):
+    app.help = "This is the App's Help."
+    app.help_on_error = True
+
+    @app.command
+    def foo(count: int):
+        """This is Foo's Help."""
+        pass
+
+    with console.capture() as capture, pytest.raises(CoercionError):
+        app(["foo", "bar"], console=console, exit_on_error=False)
+
+    actual = capture.get()
+    expected = dedent(
+        """\
+        Usage: app foo [ARGS] [OPTIONS]
+
+        This is Foo's Help.
+
+        ╭─ Parameters ───────────────────────────────────────────────────────╮
+        │ *  COUNT --count  [required]                                       │
+        ╰────────────────────────────────────────────────────────────────────╯
+        ╭─ Error ────────────────────────────────────────────────────────────╮
+        │ Invalid value for "COUNT": unable to convert "bar" into int.       │
+        ╰────────────────────────────────────────────────────────────────────╯
+        """
+    )
+    assert actual == expected
